## ----include=FALSE------------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----vignetteSetup, echo=FALSE, message=FALSE, warning=FALSE------------------
## Track time spent on making the vignette
startTime <- Sys.time()

## Bib setup
library(RefManageR)

## Write bibliography information
bib <- c(
    R = citation(),
    BiocStyle = citation("BiocStyle")[1],
    knitr = citation("knitr")[1],
    RefManageR = citation("RefManageR")[1],
    rmarkdown = citation("rmarkdown")[1],
    testthat = citation("testthat")[1]
)

## ----install, eval=FALSE------------------------------------------------------
#  remotes::install_github("RiboRings/iSEEtree")

## ----citation-----------------------------------------------------------------
## Citation info
citation("iSEEtree")

## ----start, message=FALSE, warning=FALSE--------------------------------------
library(iSEEtree)
library(mia)
library(scater)

# Import TreeSE
data("Tengeler2020", package = "mia")
tse <- Tengeler2020

# Add relabundance assay
tse <- transformAssay(tse, method = "relabundance")

# Add reduced dimensions
tse <- runMDS(tse, assay.type = "relabundance")

# Launch iSEE
if (interactive()) {
  iSEE(tse)
}

## ----screenfun, eval=!exists("SCREENSHOT"), include=FALSE---------------------
SCREENSHOT <- function(x, ...) knitr::include_graphics(x)

## ----screenplot, echo=FALSE, out.width="100%"---------------------------------
SCREENSHOT("screenshots/get_started.png", delay=20)

## ----createVignette, eval=FALSE-----------------------------------------------
#  ## Create the vignette
#  library(rmarkdown)
#  system.time(render("iSEEtree.Rmd", "BiocStyle::html_document"))
#  
#  ## Extract the R code
#  library(knitr)
#  knit("iSEEtree.Rmd", tangle = TRUE)

## ----reproduce1, echo=FALSE---------------------------------------------------
## Date the vignette was generated
Sys.time()

## ----reproduce2, echo=FALSE---------------------------------------------------
## Processing time in seconds
totalTime <- diff(c(startTime, Sys.time()))
round(totalTime, digits = 3)

## ----reproduce3, echo=FALSE-------------------------------------------------------------------------------------------
## Session info
options(width = 120)
sessionInfo()

## ----vignetteBiblio, results="asis", echo=FALSE, warning=FALSE, message=FALSE-----------------------------------------
## Print bibliography
PrintBibliography(bib, .opts = list(hyperlink = "to.doc", style = "html"))

